@@ -17,15 +17,17 @@ except ImportError:
     pass
 import urllib2
 from urllib import urlencode
-
+import os.path
 from lxml import etree
 import csv
+from StringIO import StringIO
 
 class AbstractViewer(object):
 
     id = 'abstractviewer' #you may insert another meaningful ID here, no spaces or special chars!
     name = "Unspecified Viewer" 
-
+    mimetype = 'text/html'
+    
     def __init__(self, **kwargs):
         self.embed = False #Embed external sites as opposed to redirecting?
         for key, value in kwargs.items():
@@ -98,28 +100,27 @@ class FoLiAViewer(AbstractViewer):
     name = "FoLiA Viewer"
 
     def view(self, file, **kwargs):
-        xslfile = "static/folia.xsl"
+        xslfile = os.path.dirname(__file__) + "/../static/folia.xsl"
         xslt_doc = etree.parse(xslfile)
         transform = etree.XSLT(xslt_doc)
 
-        f = file.open()
-        xml_doc = etree.parse(f.readlines())
-
+        #f = file.open()
+        xml_doc = etree.parse(StringIO("".join(file.readlines())))
         return str(transform(xml_doc))
 
 
 class SoNaRViewer(AbstractViewer):
     id = 'sonarviewer'
     name = "SoNaR Viewer"
-
+    
     def view(self, file, **kwargs):
-        xslfile = "static/sonar.xsl"
+        xslfile = os.path.dirname(__file__) + "/../static/sonar.xsl"
         xslt_doc = etree.parse(xslfile)
         transform = etree.XSLT(xslt_doc)
 
-        f = file.open()
-        xml_doc = etree.parse(f.readlines())
-
+        #f = file.open()
+        xml_doc = etree.parse(StringIO("".join(file.readlines())))
+        
         return str(transform(xml_doc))
 
 
